DeviceConfig

Struct DeviceConfig 

pub struct DeviceConfig {
    pub role: i32,
    pub serial_enabled: bool,
    pub button_gpio: u32,
    pub buzzer_gpio: u32,
    pub rebroadcast_mode: i32,
    pub node_info_broadcast_secs: u32,
    pub double_tap_as_button_press: bool,
    pub is_managed: bool,
    pub disable_triple_click: bool,
    pub tzdef: String,
    pub led_heartbeat_disabled: bool,
    pub buzzer_mode: i32,
}
Configuration

Fields

role: i32

Sets the role of node

serial_enabled: bool
👎Deprecated

Disabling this will disable the SerialConsole by not initilizing the StreamAPI Moved to SecurityConfig

button_gpio: u32

For boards without a hard wired button, this is the pin number that will be used Boards that have more than one button can swap the function with this one. defaults to BUTTON_PIN if defined.

buzzer_gpio: u32

For boards without a PWM buzzer, this is the pin number that will be used Defaults to PIN_BUZZER if defined.

rebroadcast_mode: i32

Sets the role of node

node_info_broadcast_secs: u32

Send our nodeinfo this often Defaults to 900 Seconds (15 minutes)

double_tap_as_button_press: bool

Treat double tap interrupt on supported accelerometers as a button press if set to true

is_managed: bool
👎Deprecated

If true, device is considered to be “managed” by a mesh administrator Clients should then limit available configuration and administrative options inside the user interface Moved to SecurityConfig

disable_triple_click: bool

Disables the triple-press of user button to enable or disable GPS

tzdef: Stringled_heartbeat_disabled: bool

If true, disable the default blinking LED (LED_PIN) behavior on the device

buzzer_mode: i32

Controls buzzer behavior for audio feedback Defaults to ENABLED

Implementations

Source

impl DeviceConfig

pub fn role(&self) -> Role

Returns the enum value of role, or the default if the field is set to an invalid enum value.

pub fn set_role(&mut self, value: Role)

Sets role to the provided enum value.

pub fn rebroadcast_mode(&self) -> RebroadcastMode

Returns the enum value of rebroadcast_mode, or the default if the field is set to an invalid enum value.

pub fn set_rebroadcast_mode(&mut self, value: RebroadcastMode)

Sets rebroadcast_mode to the provided enum value.

pub fn buzzer_mode(&self) -> BuzzerMode

Returns the enum value of buzzer_mode, or the default if the field is set to an invalid enum value.

pub fn set_buzzer_mode(&mut self, value: BuzzerMode)

Sets buzzer_mode to the provided enum value.