#[repr(i32)]pub enum CompassMode {
Dynamic = 0,
FixedRing = 1,
FreezeHeading = 2,
}Variants
Dynamic = 0
Compass with dynamic ring and heading
FixedRing = 1
Compass with fixed ring and heading
FreezeHeading = 2
Compass with heading and freeze option
Implementations
Sourceimpl CompassMode
impl CompassMode
Sourceimpl CompassMode
impl CompassMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.