#[repr(i32)]pub enum LocSource {
LocUnset = 0,
LocManual = 1,
LocInternal = 2,
LocExternal = 3,
}Expand description
How the location was acquired: manual, onboard GPS, external (EUD) GPS
Variants
LocUnset = 0
TODO: REPLACE
LocManual = 1
TODO: REPLACE
LocInternal = 2
TODO: REPLACE
LocExternal = 3
TODO: REPLACE
Implementations
Sourceimpl LocSource
impl LocSource
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.