pub struct ChannelFile {
pub channels: Vec<Channel>,
pub version: u32,
}Expand description
The on-disk saved channels
Fields
channels: Vec<Channel>The channels our node knows about
version: u32A version integer used to invalidate old save files when we make incompatible changes This integer is set at build time and is private to NodeDB.cpp in the device code.