MyNodeInfo

Struct MyNodeInfo 

pub struct MyNodeInfo {
    pub my_node_num: u32,
    pub reboot_count: u32,
    pub min_app_version: u32,
    pub device_id: Vec<u8>,
    pub pio_env: String,
    pub firmware_edition: i32,
    pub nodedb_count: u32,
}
Unique local debugging info for this node Note: we don’t include position or the user info, because that will come in the Sent to the phone in response to WantNodes.

Fields

my_node_num: u32

Tells the phone what our node number is, default starting value is lowbyte of macaddr, but it will be fixed if that is already in use

reboot_count: u32

The total number of reboots this node has ever encountered (well - since the last time we discarded preferences)

min_app_version: u32

The minimum app version that can talk to this device. Phone/PC apps should compare this to their build number and if too low tell the user they must update their app

device_id: Vec<u8>

Unique hardware identifier for this device

pio_env: String

The PlatformIO environment used to build this firmware

firmware_edition: i32

The indicator for whether this device is running event firmware and which

nodedb_count: u32

The number of nodes in the nodedb. This is used by the phone to know how many NodeInfo packets to expect on want_config

Implementations

Source

impl MyNodeInfo

pub fn firmware_edition(&self) -> FirmwareEdition

Returns the enum value of firmware_edition, or the default if the field is set to an invalid enum value.

pub fn set_firmware_edition(&mut self, value: FirmwareEdition)

Sets firmware_edition to the provided enum value.