PositionLite

Struct PositionLite 

pub struct PositionLite {
    pub latitude_i: i32,
    pub longitude_i: i32,
    pub altitude: i32,
    pub time: u32,
    pub location_source: i32,
}
Position with static location information only for NodeDBLite

Fields

latitude_i: i32

The new preferred location encoding, multiply by 1e-7 to get degrees in floating point

longitude_i: i32

TODO: REPLACE

altitude: i32

In meters above MSL (but see issue #359)

time: u32

This is usually not sent over the mesh (to save space), but it is sent from the phone so that the local device can set its RTC If it is sent over the mesh (because there are devices on the mesh without GPS), it will only be sent by devices which has a hardware GPS clock. seconds since 1970

location_source: i32

TODO: REPLACE

Implementations

Source

impl PositionLite

pub fn location_source(&self) -> LocSource

Returns the enum value of location_source, or the default if the field is set to an invalid enum value.

pub fn set_location_source(&mut self, value: LocSource)

Sets location_source to the provided enum value.