pub struct SecurityConfig {
pub public_key: Vec<u8>,
pub private_key: Vec<u8>,
pub admin_key: Vec<Vec<u8>>,
pub is_managed: bool,
pub serial_enabled: bool,
pub debug_log_api_enabled: bool,
pub admin_channel_enabled: bool,
}Fields
public_key: Vec<u8>The public key of the user’s device. Sent out to other nodes on the mesh to allow them to compute a shared secret key.
private_key: Vec<u8>The private key of the device. Used to create a shared key with a remote device.
admin_key: Vec<Vec<u8>>The public key authorized to send admin messages to this node.
is_managed: boolIf true, device is considered to be “managed” by a mesh administrator via admin messages Device is managed by a mesh administrator.
serial_enabled: boolSerial Console over the Stream API.“
debug_log_api_enabled: boolBy default we turn off logging as soon as an API client connects (to keep shared serial link quiet). Output live debug logging over serial or bluetooth is set to true.
admin_channel_enabled: boolAllow incoming device control over the insecure legacy admin channel.